@@ -5,11 +5,11 @@
 #  ALL RIGHTS RESERVED.
 #
 #  Authors: Revva Konstantin <k.revva@abm-jsc.ru>
+import time
 from abc import ABC
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Optional, Type
 import json
-
 from http_tools.http_server_connector import HttpServerConnector
 from init_helpers.dict_to_dataclass import dict_to_dataclass
 from init_helpers.custom_json import custom_dumps
@@ -19,7 +19,7 @@ from time_tools import Timerange
 @dataclass(kw_only=True, frozen=True)
 class DetectorSettings(ABC):
     rtsp_url: str
-    created_at: float | None = None
+    created_at: float = field(default_factory=time.time)
 
 
 class DetectorHttpConnector:
